==> content_feedback-8.x-1.0.tar.gz: content_feedback/src/Form/ContentFeedbackClass.php <==
<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Database\Database;

/**
 * CRUD functions for ContentFeedback.
 */
class ContentFeedbackClass {

  /**
   * Inserting new content feedback
   *
   * @param string $name
   *   Name of submitter.
   * @param string $email
   *   Email of submitter.
   * @param string $message
   *   Feedback message.
   * @param string $path
   *   Page url where feedback given.
   * @param string $ipaddress
   *   IP Address.
   * @param int $timestamp
   *   Current Timestamp.
   *
   * @throws \Exception
   */
  public static function add($name, $email, $message, $path, $ipaddress, $timestamp) {
    $connection = Database::getConnection();
    $connection->insert('content_feedback')->fields(
      [
        'name' => $name,
        'email' => $email,
        'message' => $message,
        'path' => $path,
        'ipaddress' => $ipaddress,
        'created' => $timestamp,
        'updated' => $timestamp,
      ]
    )->execute();
  }

  /**
   * Get all content feedbacks.
   *
   * @return array
   *   Return associative array of all feedbacks.
   */
  public static function getAll($header) {
    $connection = Database::getConnection();
    $list = $connection->select('content_feedback', 'cf')
      ->fields('cf',
        ['id', 'name', 'email', 'message', 'path', 'ipaddress', 'status', 'updated']
      );
    $table_sort = $list->extend('Drupal\Core\Database\Query\TableSortExtender')->orderByHeader($header);
    $executed = $table_sort->execute();
    $results = $executed->fetchAllAssoc('id', \PDO::FETCH_OBJ);

    return $results;
  }

  /**
   * Get content feedback details.
   *
   * @param int $id
   *   Id of feedback.
   *
   * @return array
   *   Return associative array of feedback.
   */
  public static function getFeedback($id) {
    $connection = Database::getConnection();
    $feedback = $connection->select('content_feedback', 'cf')
      ->fields('cf', ['id', 'name', 'email', 'message', 'path', 'ipaddress', 'status'])
      ->condition('id', $id);
    $executed = $feedback->execute();
    $result = $executed->fetchAssoc();

    return $result;
  }

  /**
   * Check if content feedback exists.
   *
   * @return bool
   *   Returns if Feedback exists or not
   */
  public static function checkFeedback($id) {
    $connection = Database::getConnection();
    $check = $connection->select('content_feedback', 'cf')
      ->fields('cf', ['id'])
      ->condition('id', $id)
      ->countQuery()
      ->execute()
      ->fetchField();

    return $check;
  }

  /**
   * Update content feedback.
   *
   * @return int
   *   Returns id of the updated content feedback.
   *
   * @throws \Exception
   */
  public static function updateFeedback($status, $name, $email, $ip, $message, $path, $id) {
    $connection = Database::getConnection();
    $updated = $connection->update('content_feedback')
      ->fields(
        [
          'status' => $status,
          'name' => $name,
          'email' => $email,
          'ipaddress' => $ip,
          'message' => $message,
          'path' => $path,
          'updated' => time(),
        ]
      )
      ->condition('id', $id)
      ->execute();

    return $updated;
  }

  /**
   * Delete content feedback.
   *
   * @param int $id
   *   Id of content feedback to be deleted.
   */
  public static function deleteFeedback($id) {
    $connection = Database::getConnection();
    $connection->delete('content_feedback')
      ->condition('id', $id)
      ->execute();
  }

}

==> content_feedback-8.x-1.1.tar.gz: content_feedback/src/Form/ContentFeedbackClass.php <==
<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Database\Database;

/**
 * CRUD functions for ContentFeedback.
 */
class ContentFeedbackClass {

  /**
   * Inserting new content feedback.
   *
   * @param string $name
   *   Name of submitter.
   * @param string $email
   *   Email of submitter.
   * @param string $message
   *   Feedback message.
   * @param string $path
   *   Page url where feedback given.
   * @param string $ipaddress
   *   IP Address.
   * @param int $timestamp
   *   Current Timestamp.
   *
   * @throws \Exception
   */
  public static function addContentFeedback($name, $email, $message, $path, $ipaddress, $timestamp) {
    $connection = Database::getConnection();
    $connection->insert('content_feedback')->fields(
      [
        'name' => $name,
        'email' => $email,
        'message' => $message,
        'path' => $path,
        'ipaddress' => $ipaddress,
        'created' => $timestamp,
        'updated' => $timestamp,
      ]
    )->execute();
  }

  /**
   * Get all content feedbacks.
   *
   * @return array
   *   Return associative array of all feedbacks.
   */
  public static function getAllContentFeedbacks($header) {
    $connection = Database::getConnection();
    $fields = [
      'id',
      'name',
      'email',
      'message',
      'path',
      'ipaddress',
      'status',
      'updated',
    ];
    $list = $connection->select('content_feedback', 'cf')
      ->fields('cf', $fields);
    $table_sort = $list->extend('Drupal\Core\Database\Query\TableSortExtender')->orderByHeader($header);
    $executed = $table_sort->execute();
    $results = $executed->fetchAllAssoc('id', \PDO::FETCH_OBJ);

    return $results;
  }

  /**
   * Get content feedback details.
   *
   * @param int $id
   *   Id of feedback.
   *
   * @return array
   *   Return associative array of feedback.
   */
  public static function getFeedbackById($id) {
    $connection = Database::getConnection();
    $fields = [
      'id',
      'name',
      'email',
      'message',
      'path',
      'ipaddress',
      'status',
    ];
    $feedback = $connection->select('content_feedback', 'cf')
      ->fields('cf', $fields)
      ->condition('id', $id);
    $executed = $feedback->execute();
    $result = $executed->fetchAssoc();

    return $result;
  }

  /**
   * Check if content feedback exists.
   *
   * @return bool
   *   Returns if feedback exists or not.
   */
  public static function checkFeedback($id) {
    $connection = Database::getConnection();
    $check = $connection->select('content_feedback', 'cf')
      ->fields('cf', ['id'])
      ->condition('id', $id)
      ->countQuery()
      ->execute()
      ->fetchField();

    return $check;
  }

  /**
   * Update content feedback.
   *
   * @return int
   *   Returns id of the updated content feedback.
   *
   * @throws \Exception
   */
  public static function updateFeedback($status, $name, $email, $ip, $message, $path, $id) {
    $connection = Database::getConnection();
    $updated = $connection->update('content_feedback')
      ->fields(
        [
          'status' => $status,
          'name' => $name,
          'email' => $email,
          'ipaddress' => $ip,
          'message' => $message,
          'path' => $path,
          'updated' => time(),
        ]
      )
      ->condition('id', $id)
      ->execute();

    return $updated;
  }

  /**
   * Delete content feedback.
   *
   * @param int $id
   *   Id of content feedback to be deleted.
   */
  public static function deleteContentFeedback($id) {
    $connection = Database::getConnection();
    $connection->delete('content_feedback')
      ->condition('id', $id)
      ->execute();
  }

}
